:orphan:

Data sources (MongoDB)
----------------------

We're currently working on updating this example, sorry for the inconvenience!

In the meantime, feel free to check out the `Dask-Mongo project <https://github.com/coiled/dask-mongo>`_
or other :doc:`examples <../examples>` of how to use Coiled in a variety of use cases.